# ewoks3dxrd

Ewoks 3DXRD workflows based on [ImageD11](https://github.com/FABLE-3DXRD/ImageD11)

⚠️ Work in progress! ⚠️

## Quick start

```code
pip install ewoks3dxrd
```


## Documentation

https://ewoks3dxrd.readthedocs.io/
